@@ -7,7 +7,7 @@ class StringField(models.Field):
     description = _("String")
 
     def __init__(self, *args, **kwargs):
-        kwargs['max_length'] = kwargs.get('max_length', 255)
+        kwargs['max_length'] = kwargs.get('max_length', 500)
         super(StringField, self).__init__(*args, **kwargs)
 
     def get_internal_type(self):
@@ -31,6 +31,8 @@ class StringField(models.Field):
             return 'character varying'
         if connection.vendor == 'mysql':
             return 'VARCHAR (65528)'
+        if connection.vendor == 'oracle':
+            return 'VARCHAR2 (4000)'
         return 'TEXT'
 
     def south_field_triple(self):
